@@ -113,7 +113,7 @@ class Pg:
         print(one_column)
         enums = enumerate(opt.keys(), 1)
         columns = ' AND '.join(f'{c} = ${i}' for i, c in enums if i != 1) 
-        print(f'カラム: {columns}' if columns is None else '無し')
+        print('無し' if not columns else f'カラム: {columns}')
 
         if columns is None:
             return await self.pool.execute(f'UPDATE {self.table} SET {one_column}', *opt.values())
